searchData={"items":[{"type":"module","title":"Geo.Turf","doc":"# Geo.Turf\n\nAn Elixir spatial analysis tool for the [Geo](https://github.com/bryanjos/geo) library ported from [TurfJS](http://turfjs.org/).","ref":"Geo.Turf.html"},{"type":"module","title":"Warning - Geo.Turf","doc":"*At the moment the library is in early development mode. The API could, and propably will, change on any moment.*","ref":"Geo.Turf.html#module-warning"},{"type":"module","title":"Usage - Geo.Turf","doc":"The library can perform functions on [Geo](https://github.com/bryanjos/geo) objects as well as basic mathematic functions useful in spatial analysis. At the moment Geo.Turf expects WGS84 coordinates.\n\nFor example:\n\n  * `Geo.Turf.Measure.along/3`: Make a `%Geo.Point{}` at a definded distance from the start of a `%Geo.LineString{}` .\n  * `Geo.Turf.Measure.along_midpoint/1`: Make a `%Geo.Point{}` at a the middle of a `%Geo.LineString{}` .\n  * `Geo.Turf.Measure.center/1`: Makes a `%Geo.Point{}` at the center of a Feature.\n  * `Geo.Turf.Measure.close_to/4`: Check if 2 `%Geo.Point{}` items are close to each other.\n  * `Geo.Turf.Measure.distance/3`: Check the distance between 2 `%Geo.Point{}` items.\n  * `Geo.Turf.Measure.length_of/2`: Gives the length of a `%Geo.LineString{}` or the circumference of a `%Geo.Polygon{}`","ref":"Geo.Turf.html#module-usage"},{"type":"module","title":"Suggestions - Geo.Turf","doc":"If there are functions you need from [TurfJS](http://turfjs.org/) or just things you thought of please just make an issue for it. Including a test for it would be great.","ref":"Geo.Turf.html#module-suggestions"},{"type":"type","title":"Geo.Turf.coordinates/0","doc":"","ref":"Geo.Turf.html#t:coordinates/0"},{"type":"type","title":"Geo.Turf.point/0","doc":"","ref":"Geo.Turf.html#t:point/0"},{"type":"module","title":"Geo.Turf.Helpers","doc":"A collection of helper utilities.\nUsually users will not have to refer to this directly but it is here\nif the need arises.","ref":"Geo.Turf.Helpers.html"},{"type":"function","title":"Geo.Turf.Helpers.bbox/1","doc":"Create a bounding box for a given `t:Geo.geometry/0`.","ref":"Geo.Turf.Helpers.html#bbox/1"},{"type":"function","title":"Examples - Geo.Turf.Helpers.bbox/1","doc":"iex> Geo.Turf.Helpers.bbox(%Geo.Polygon{coordinates: [{1,1}, {1,3}, {3,3}, {3,1}]})\n    {1,1,3,3}\n\n    iex> Geo.Turf.Helpers.bbox([{1,1},{2,2},{3,3}])\n    {1,1,3,3}","ref":"Geo.Turf.Helpers.html#bbox/1-examples"},{"type":"function","title":"Geo.Turf.Helpers.flatten_coords/1","doc":"Flatten a `t:Geo.geometry()` to a simple list of coordinates","ref":"Geo.Turf.Helpers.html#flatten_coords/1"},{"type":"function","title":"Examples - Geo.Turf.Helpers.flatten_coords/1","doc":"iex> Geo.Turf.Helpers.flatten_coords(%Geo.GeometryCollection{geometries: [\n    ...>  %Geo.Point{coordinates: {1,1}},\n    ...>  %Geo.Point{coordinates: {2,2}}\n    ...> ]})\n    [{1,1}, {2,2}]","ref":"Geo.Turf.Helpers.html#flatten_coords/1-examples"},{"type":"module","title":"Geo.Turf.Math","doc":"All sorts of mathematical functions","ref":"Geo.Turf.Math.html"},{"type":"function","title":"Geo.Turf.Math.bearing_to_azimuth/1","doc":"","ref":"Geo.Turf.Math.html#bearing_to_azimuth/1"},{"type":"function","title":"Geo.Turf.Math.convert_area/3","doc":"","ref":"Geo.Turf.Math.html#convert_area/3"},{"type":"function","title":"Geo.Turf.Math.convert_length/3","doc":"","ref":"Geo.Turf.Math.html#convert_length/3"},{"type":"function","title":"Geo.Turf.Math.degrees_to_radians/1","doc":"","ref":"Geo.Turf.Math.html#degrees_to_radians/1"},{"type":"function","title":"Geo.Turf.Math.length_to_degrees/2","doc":"","ref":"Geo.Turf.Math.html#length_to_degrees/2"},{"type":"function","title":"Geo.Turf.Math.length_to_radians/2","doc":"","ref":"Geo.Turf.Math.html#length_to_radians/2"},{"type":"function","title":"Geo.Turf.Math.mod/2","doc":"Calculates the modulo of a number (integer or float).\n\nNote that this function uses `floored division` whereas the builtin `rem`\nfunction uses `truncated division`. See `Decimal.rem/2` if you want a\n`truncated division` function for Decimals that will return the same value as\nthe BIF `rem/2` but in Decimal form.\n\nSee [Wikipedia](https://en.wikipedia.org/wiki/Modulo_operation) for an\nexplanation of the difference.\n\nTaken from [cldr_utils](https://hex.pm/packages/cldr_utils) with thanks and gratitude.","ref":"Geo.Turf.Math.html#mod/2"},{"type":"function","title":"Examples - Geo.Turf.Math.mod/2","doc":"iex> Geo.Turf.Math.mod(1234.0, 5)\n    4.0","ref":"Geo.Turf.Math.html#mod/2-examples"},{"type":"function","title":"Geo.Turf.Math.radians_to_degrees/1","doc":"","ref":"Geo.Turf.Math.html#radians_to_degrees/1"},{"type":"function","title":"Geo.Turf.Math.radians_to_length/2","doc":"","ref":"Geo.Turf.Math.html#radians_to_length/2"},{"type":"function","title":"Geo.Turf.Math.rounded/2","doc":"Round number to precision","ref":"Geo.Turf.Math.html#rounded/2"},{"type":"function","title":"Example - Geo.Turf.Math.rounded/2","doc":"iex> Geo.Turf.Math.rounded(120.4321)\n    120\n\n    iex> Geo.Turf.Math.rounded(120.4321, 3)\n    120.432","ref":"Geo.Turf.Math.html#rounded/2-example"},{"type":"type","title":"Geo.Turf.Math.imperial_length/0","doc":"","ref":"Geo.Turf.Math.html#t:imperial_length/0"},{"type":"type","title":"Geo.Turf.Math.length_unit/0","doc":"","ref":"Geo.Turf.Math.html#t:length_unit/0"},{"type":"type","title":"Geo.Turf.Math.si_length_uk/0","doc":"","ref":"Geo.Turf.Math.html#t:si_length_uk/0"},{"type":"type","title":"Geo.Turf.Math.si_length_us/0","doc":"","ref":"Geo.Turf.Math.html#t:si_length_us/0"},{"type":"module","title":"Geo.Turf.Measure","doc":"A collection of measurement related tools","ref":"Geo.Turf.Measure.html"},{"type":"function","title":"Geo.Turf.Measure.along/3","doc":"Takes a LineString and returns a Point at a specified distance along the line.\nNote that this will aproximate location to the nearest coordinate point.","ref":"Geo.Turf.Measure.html#along/3"},{"type":"function","title":"Examples - Geo.Turf.Measure.along/3","doc":"iex> %Geo.LineString{coordinates: [{-23.621,64.769},{-23.629,64.766},{-23.638,64.766}]}\n    ...>   |> Geo.Turf.Measure.along(400, :meters)\n    %Geo.Point{coordinates: {-23.629,64.766}}","ref":"Geo.Turf.Measure.html#along/3-examples"},{"type":"function","title":"Geo.Turf.Measure.along_midpoint/1","doc":"Takes a LineString and returns a Point at the middle of the line.","ref":"Geo.Turf.Measure.html#along_midpoint/1"},{"type":"function","title":"Examples - Geo.Turf.Measure.along_midpoint/1","doc":"iex> %Geo.LineString{coordinates: [{-23.621,64.769},{-23.629,64.766},{-23.638,64.766}]}\n    ...>   |> Geo.Turf.Measure.along_midpoint()\n    %Geo.Point{coordinates: {-23.629, 64.766}}","ref":"Geo.Turf.Measure.html#along_midpoint/1-examples"},{"type":"function","title":"Geo.Turf.Measure.area/1","doc":"Takes a feature or collection and returns their area in square meters.","ref":"Geo.Turf.Measure.html#area/1"},{"type":"function","title":"Examples - Geo.Turf.Measure.area/1","doc":"iex> %Geo.Polygon{coordinates: [[{125, -15}, {113, -22}, {154, -27}, {144, -15}, {125, -15}]]}\n    ...>   |> Geo.Turf.Measure.area()\n    3332484969239.2676","ref":"Geo.Turf.Measure.html#area/1-examples"},{"type":"function","title":"Geo.Turf.Measure.bearing/2","doc":"Takes two points and finds the geographic bearing between them,\ni.e. the angle measured in degrees from the north line (0 degrees)","ref":"Geo.Turf.Measure.html#bearing/2"},{"type":"function","title":"Examples - Geo.Turf.Measure.bearing/2","doc":"iex> point1 = %Geo.Point{coordinates: {-75.343, 39.984}}\n    ...> point2 = %Geo.Point{coordinates: {-75.534, 39.123}}\n    ...> Geo.Turf.Measure.bearing(point1, point2)\n    ...>  |> Geo.Turf.Math.rounded(2)\n    -170.23","ref":"Geo.Turf.Measure.html#bearing/2-examples"},{"type":"function","title":"Geo.Turf.Measure.center/1","doc":"Find the center of a `Geo.geometry()` item and give us a `Geo.Point`","ref":"Geo.Turf.Measure.html#center/1"},{"type":"function","title":"Examples - Geo.Turf.Measure.center/1","doc":"iex> Geo.Turf.Measure.center(%Geo.Polygon{coordinates: [{0,0}, {0,10}, {10,10}, {10,0}]})\n    %Geo.Point{ coordinates: {5, 5} }","ref":"Geo.Turf.Measure.html#center/1-examples"},{"type":"function","title":"Geo.Turf.Measure.close_to/4","doc":"Verifies that two points are close to each other. Defaults to 100 meters.","ref":"Geo.Turf.Measure.html#close_to/4"},{"type":"function","title":"Examples - Geo.Turf.Measure.close_to/4","doc":"iex> %Geo.Point{coordinates: {-22.653375, 64.844254}}\n    ...> |> Geo.Turf.Measure.close_to(%Geo.Point{coordinates: {-22.654042, 64.843656}})\n    true\n\n    iex> %Geo.Point{coordinates: {-22.653375, 64.844254}}\n    ...> |> Geo.Turf.Measure.close_to(%Geo.Point{coordinates: {-23.803020, 64.730435}}, 100, :kilometers)\n    true","ref":"Geo.Turf.Measure.html#close_to/4-examples"},{"type":"function","title":"Geo.Turf.Measure.distance/3","doc":"Calculates the distance between two points in degrees, radians, miles, or kilometers.\nThis uses the [Haversine formula](http://en.wikipedia.org/wiki/Haversine_formula) to account for global curvature.","ref":"Geo.Turf.Measure.html#distance/3"},{"type":"function","title":"Examples - Geo.Turf.Measure.distance/3","doc":"iex> Geo.Turf.Measure.distance(\n    ...>   %Geo.Point{coordinates: {-75.343, 39.984}},\n    ...>   %Geo.Point{coordinates: {-75.534, 39.123}},\n    ...>   :kilometers)\n    97.13","ref":"Geo.Turf.Measure.html#distance/3-examples"},{"type":"function","title":"Geo.Turf.Measure.length_of/2","doc":"Takes a `t:Geo.geometry()` and measures its length in the specified units.","ref":"Geo.Turf.Measure.html#length_of/2"},{"type":"function","title":"Examples - Geo.Turf.Measure.length_of/2","doc":"iex> %Geo.LineString{coordinates: [{-23.621,64.769},{-23.629,64.766},{-23.638,64.766}]}\n    ...>   |> Geo.Turf.Measure.length_of()\n    0.93","ref":"Geo.Turf.Measure.html#length_of/2-examples"}],"content_type":"text/markdown"}